#[non_exhaustive]pub enum BuildError {
UnsupportedFormat,
DepthStencilPremultipliedAlpha,
DepthStencilTransferFunction,
DepthStencilColorPrimaries,
DepthStencilColorModel,
CompressedColorModel,
SrgbTransferNotAllowed,
SrgbTransferRequired,
}Expand description
Error type for DFD generation and validation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
UnsupportedFormat
The Format is not recognized by the DFD generation table.
DepthStencilPremultipliedAlpha
Premultiplied alpha was requested for a depth-stencil format, which has no alpha channel.
DepthStencilTransferFunction
A transfer function override was specified for a depth-stencil format. Depth-stencil formats always use linear transfer.
DepthStencilColorPrimaries
A color primaries override was specified for a depth-stencil format. Depth-stencil formats always use BT.709 primaries.
DepthStencilColorModel
A color model override was specified for a depth-stencil format. Depth-stencil formats always use RGBSDA.
CompressedColorModel
A color model override was specified for a compressed format. Compressed formats must use their intrinsic color model.
SrgbTransferNotAllowed
The transfer function was set to sRGB, but this format has a dedicated sRGB variant. Use the sRGB variant of the format instead.
SrgbTransferRequired
The transfer function was overridden to a non-sRGB value, but this format is an sRGB variant and must use sRGB transfer.