pub struct BlockHeader {
pub vendor_id: u32,
pub descriptor_type: u32,
pub version_number: u16,
}Expand description
DFD block header, containing what type and version of block.
Implementations can skip blocks with unrecognized headers, allowing unknown data to be ignored.
Fields
vendor_id: u3217-bit organization identifier. 0 is Khronos. PCI SIG IDs use bits 0–15 with bit 16
clear; other IDs are assigned by Khronos starting at 65536.
descriptor_type: u3215-bit vendor-defined identifier distinguishing between data representations.
version_number: u16Vendor-defined version, intended for backwards-compatible updates to a descriptor block.
Implementations
Sourceimpl BlockHeader
impl BlockHeader