pub struct ChannelTypeQualifiers(/* private fields */);Expand description
Qualifiers modifying the channel type of a SampleInformation entry.
Multiple samples with the same channel and position are combined into a single logical
(“virtual”) sample. Samples without EXPONENT set contribute to the
base value — the primary numeric content of the channel (e.g. a color intensity or
mantissa). Samples with EXPONENT set act as modifiers that
transform the base value — the interpretation depends on the combination of flags:
EXPONENT | LINEAR | FLOAT | Interpretation |
|---|---|---|---|
| - | - | - | Base value, modified by TransferFunction |
| - | L | - | Base value, always linear (ignores TransferFunction) |
| - | - | F | Base value is a standard float (10/11/16/32/64-bit) |
| E | - | - | Exponent: base × 2^modifier |
| E | - | F | Multiplier: base × modifier |
| E | L | - | Divisor: base / modifier |
| E | L | F | Power: base ^ modifier |
For a long and more confusing explanation of this, see the DFD specification.
Implementations
Sourceimpl ChannelTypeQualifiers
impl ChannelTypeQualifiers
Sourcepub const LINEAR: Self
pub const LINEAR: Self
The sample contains a linearly-encoded value, bypassing the format’s
TransferFunction. When combined with EXPONENT, indicates a
divisor modifier instead.
Sourcepub const EXPONENT: Self
pub const EXPONENT: Self
The sample is a modifier applied to the base value rather than part of the base value
itself. The type of modification depends on the LINEAR and
FLOAT flags — see the table on ChannelTypeQualifiers.
Sourcepub const SIGNED: Self
pub const SIGNED: Self
The sample holds a signed two’s complement value. When not set, the sample is unsigned.
Sourceimpl ChannelTypeQualifiers
impl ChannelTypeQualifiers
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<Self>
pub const fn from_bits(bits: u8) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> Self
pub const fn from_bits_truncate(bits: u8) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> Self
pub const fn from_bits_retain(bits: u8) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl ChannelTypeQualifiers
impl ChannelTypeQualifiers
Sourcepub const fn iter(&self) -> Iter<ChannelTypeQualifiers>
pub const fn iter(&self) -> Iter<ChannelTypeQualifiers>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ChannelTypeQualifiers>
pub const fn iter_names(&self) -> IterNames<ChannelTypeQualifiers>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.